/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include <vector>
 
#include "chttextcontrol.hh"
#include "chtfiledroptarget.hh"
#include "../tools/chtfilereader.hh"
#include "../exceptions/invalidchtfileexception.hh"

CHTTextControl::CHTTextControl(CHTFrame *parent) :
    wxTextCtrl(parent, -1, wxEmptyString, wxDefaultPosition,
        wxDefaultSize, wxTE_MULTILINE | wxTE_READONLY | wxTE_RICH) {
    this->parent = parent;
    SetFont(wxFont(12, wxMODERN, wxNORMAL, wxNORMAL));
    SetDropTarget(new CHTFileDropTarget(this));
}

bool CHTTextControl::readCHTFile(wxString &filename) {
    try {
        CHTFileReader &reader = CHTFileReader::getInstance();
        std::vector<CHTCode> &list = reader.readCHTFile(filename);
        wxString code;
        code.Alloc(50);
            
        Clear();
            
        for (size_t i = 0; i < list.size(); i++) {
            code.Clear();
            code.Printf("%2d: %s\n", (i + 1), 
                        list[i].toString().c_str());
            AppendText(code);
        }
        
        if (list.size() > 0) {
            parent->fileMenu->Enable(IDM_FILE_SAVE, true);
        }
    } catch (InvalidCHTFileException e) {
        wxMessageDialog dlg(this, filename + " is not a valid .CHT file",
                            "Invalid .CHT File", wxOK | wxICON_ERROR);
        dlg.ShowModal();
        
        return false;
    }
    
    return true;
}

